@@ -43,8 +43,37 @@ class GitHub2GitLab:
         'close': 'closed',
     }
 
-    def __init__(self, argv):
-        self.parse_args(argv)
+    def __init__(self, args):
+        self.args = args
+
+        self.args.ssh_public_key = os.path.expanduser(
+            self.args.ssh_public_key
+        )
+
+        if not self.args.gitlab_repo:
+            self.args.gitlab_repo = self.args.github_repo
+        (self.args.gitlab_namespace,
+         self.args.gitlab_name) = self.args.gitlab_repo.split('/')
+        self.args.gitlab_repo = urllib.quote_plus(self.args.gitlab_repo)
+
+        self.github = {
+            'url': "https://api.github.com",
+            'git': "https://github.com",
+            'repo': self.args.github_repo,
+            'token': self.args.github_token,
+        }
+        if self.args.branches:
+            self.github['branches'] = self.args.branches.split(',')
+        self.gitlab = {
+            'git': self.args.gitlab_url.replace('http://', 'git@'),
+            'host': self.args.gitlab_url,
+            'name': self.args.gitlab_name,
+            'namespace': self.args.gitlab_namespace,
+            'url': self.args.gitlab_url + "/api/v3",
+            'repo': self.args.gitlab_repo,
+            'token': self.args.gitlab_token,
+        }
+
         if self.args.verbose:
             level = logging.DEBUG
         else:
@@ -90,36 +119,9 @@ class GitHub2GitLab:
                             help='cache GitHub pull requests list')
         return parser
 
-    def parse_args(self, argv):
-        self.args = self.get_parser().parse_args(argv)
-
-        self.args.ssh_public_key = os.path.expanduser(
-            self.args.ssh_public_key
-        )
-
-        if not self.args.gitlab_repo:
-            self.args.gitlab_repo = self.args.github_repo
-        (self.args.gitlab_namespace,
-         self.args.gitlab_name) = self.args.gitlab_repo.split('/')
-        self.args.gitlab_repo = urllib.quote_plus(self.args.gitlab_repo)
-
-        self.github = {
-            'url': "https://api.github.com",
-            'git': "https://github.com",
-            'repo': self.args.github_repo,
-            'token': self.args.github_token,
-        }
-        if self.args.branches:
-            self.github['branches'] = self.args.branches.split(',')
-        self.gitlab = {
-            'git': self.args.gitlab_url.replace('http://', 'git@'),
-            'host': self.args.gitlab_url,
-            'name': self.args.gitlab_name,
-            'namespace': self.args.gitlab_namespace,
-            'url': self.args.gitlab_url + "/api/v3",
-            'repo': self.args.gitlab_repo,
-            'token': self.args.gitlab_token,
-        }
+    @staticmethod
+    def factory(argv):
+        return GitHub2GitLab(GitHub2GitLab.get_parser().parse_args(argv))
 
     def run(self):
         self.add_key()
@@ -130,6 +132,7 @@ class GitHub2GitLab:
         self.merge_requests = self.get_merge_requests()
         self.update_merge_pull()
         self.sync()
+        return 0
 
     def sh(self, command):
         logging.debug(command)
